BezPath
=======

::

   from kurbopy import BezPath

   bez = BezPath()
   bez.move_to(Point(100, 100))
   bez.line_to(Point(100, 200))
   bez.quad_to(Point(200, 200), Point(200, 100))

.. autoclass:: kurbopy.BezPath
   :members:
   :undoc-members:
